RustcItem

Enum RustcItem 

pub enum RustcItem {
    Poly(DefId),
    Mono(ItemRef),
    MonoTrait(DefId),
}
Refers to a rustc item. Can be either the polymorphic version (Poly) of the item, or a monomorphization (Mono or MonoTrait) of it. For MonoTrait items, their kind should be either trait decl or struct vtable: 1. the trait is translated as in poly mode, except that we don’t translate any of its associated item lists. 2. the vtable is translated with erased signature of the methods and without generic types. In other words, there is one “opaque” vtable per trait.

Variants



Poly(DefId)



Mono(ItemRef)



MonoTrait(DefId)

Implementations

Source

impl RustcItem

pub fn def_id(&self) -> &DefId