pub enum TransImplSource {
Normal,
TraitAlias,
Callable(ClosureKind),
ImplicitDestruct,
}Expand description
The kind of a TransItemSourceKind::TraitImpl.
Variants
Normal
A user-written trait impl with a DefId.
TraitAlias
The blanket impl we generate for a trait alias. The DefId is that of the trait alias.
Callable(ClosureKind)
An impl of the appropriate Fn* trait for a closure or function item.
ImplicitDestruct
A fictitious impl Destruct for T that contains the drop glue code for the given ADT or
closure. The DefId is that of the ADT or closure.
Implementations
Sourceimpl TransImplSource
impl TransImplSource
pub fn variant_index_arity(&self) -> (u32, usize)