pub enum TransItemSourceKind {
Show 15 variants
Global,
TraitDecl,
TraitImpl(TransImplSource),
Fun,
Type,
InherentImpl,
Module,
CallableMethod(ClosureKind),
ClosureAsFnCast,
DropGlueMethod(TransImplSource),
VTable,
VTableInstance(TransImplSource),
VTableInstanceInitializer(TransImplSource),
VTableMethod,
VTableDropShim,
}Expand description
The kind of a TransItemSource.
Variants
Global
TraitDecl
TraitImpl(TransImplSource)
Fun
Type
InherentImpl
We don’t translate these as proper items, but we translate them a bit in names.
Module
We don’t translate these as proper items, but we use them to explore the crate.
CallableMethod(ClosureKind)
The call_* method of the generated Fn* impl for a closure or fn item.
ClosureAsFnCast
A cast of a stateless closure to a function pointer.
DropGlueMethod(TransImplSource)
The drop_glue method of a Destruct impl. It contains the drop glue that calls
Drop::drop for the type and then drops its fields. This is a method implementation (and
the DefId is that of the ADT or closure for which to generate the drop glue).
VTable
The virtual table struct definition for a trait. The DefId is that of the trait.
VTableInstance(TransImplSource)
The static vtable value for a specific impl.
VTableInstanceInitializer(TransImplSource)
The initializer function of the VTableInstance.
VTableMethod
Shim function to store a method in a vtable; give a method with self: Ptr<Self> argument,
this takes a Ptr<dyn Trait> and forwards to the method. The DefId refers to the method
implementation.
VTableDropShim
The drop shim function to be used in the vtable as a field, the DefId is an impl.
Implementations
Sourceimpl TransItemSourceKind
impl TransItemSourceKind
pub fn variant_index_arity(&self) -> (u32, usize)
Sourceimpl TransItemSourceKind
impl TransItemSourceKind
pub fn is_for_trait(&self) -> bool